More asserts around physreg uses

git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@103685 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/RegAllocFast.cpp b/lib/CodeGen/RegAllocFast.cpp
index eac8407..304162a 100644
--- a/lib/CodeGen/RegAllocFast.cpp
+++ b/lib/CodeGen/RegAllocFast.cpp
@@ -487,7 +487,7 @@
 }
 
 /// reservePhysReg - Mark PhysReg as reserved. This is very similar to
 /// defineVirtReg except the physreg is reverved instead of allocated.
 void RAFast::reservePhysReg(MachineBasicBlock &MBB, MachineInstr *MI,
                             unsigned PhysReg) {
   UsedInInstr.set(PhysReg);
@@ -623,6 +623,16 @@
       if (!Reg || !TargetRegisterInfo::isPhysicalRegister(Reg) ||
           ReservedRegs.test(Reg)) continue;
       if (MO.isUse()) {
+#ifndef NDEBUG
+        // We are using a physreg directly. It had better not be clobbered by a
+        // virtreg.
+        assert(PhysRegState[Reg] <= regReserved && "Using clobbered physreg");
+        if (PhysRegState[Reg] == regDisabled)
+          for (const unsigned *AS = TRI->getAliasSet(Reg);
+               unsigned Alias = *AS; ++AS)
+            assert(PhysRegState[Alias] <= regReserved &&
+                   "Physreg alias was clobbered");
+#endif
         PhysKills.push_back(Reg); // Any clean physreg use is a kill.
         UsedInInstr.set(Reg);
       } else if (MO.isEarlyClobber()) {
@@ -487,7 +487,7 @@
 
 /// reservePhysReg - Mark PhysReg as reserved. This is very similar to
-/// defineVirtReg except the physreg is reverved instead of allocated.
+/// defineVirtReg except the physreg is reserved instead of allocated.
 void RAFast::reservePhysReg(MachineBasicBlock &MBB, MachineInstr *MI,
                             unsigned PhysReg) {